==> ledgereth-0.1.0.tar.gz: ledgereth-0.1.0/ledgereth/objects.py <==
import rlp
from rlp.sedes import big_endian_int, binary, Binary

from ledgereth.utils import is_bytes


class ISO7816Command:
    def __init__(self, CLA: bytes, INS: bytes, P1: bytes, P2: bytes, Lc: bytes = None,
                 Le: bytes = None, data: bytes = None):
        try:
            assert is_bytes(CLA)
            assert is_bytes(INS)
            assert is_bytes(P1)
            assert is_bytes(P2)
            assert is_bytes(Lc) or Lc is None
            assert is_bytes(Le) or Le is None
            assert is_bytes(data) or data is None
        except AssertionError:
            raise ValueError("Command parts must be type bytes")

        self.CLA = CLA
        self.INS = INS
        self.P1 = P1
        self.P2 = P2
        self.Lc = Lc or b'\x00'
        self.Le = Le
        self.data = data

    def set_data(self, data: bytes, Lc: bytes = None) -> None:
        self.data = data
        if len(self.data) > 255:
            # TODO: Warning?
            return
        if Lc is None:
            self.Lc = len(self.data).to_bytes(1, 'big')
        else:
            self.Lc = Lc

    def encode(self) -> bytes:
        encoded = self.CLA + self.INS + self.P1 + self.P2
        if self.data is not None:
            if self.Lc is None:
                self.Lc = (len(self.data)).to_bytes(1, 'big')
            encoded += self.Lc
            encoded += self.data
        else:
            encoded += self.Lc
        if self.Le is not None:
            encoded += self.Le
        return encoded

    def encode_hex(self) -> str:
        return self.encode().hex()


class RLPTx(rlp.Serializable):
    fields = [
        ('nonce', big_endian_int),
        ('gasprice', big_endian_int),
        ('startgas', big_endian_int),
        ('to', Binary.fixed_length(20, allow_empty=True)),
        ('value', big_endian_int),
        ('data', binary),
    ]

    def __init__(self, nonce: int, gasprice: int, startgas: int, to: bytes, value: int, data: str):
        super(RLPTx, self).__init__(nonce, gasprice, startgas, to, value, data)

    def sender(self, value: str) -> None:
        self._sender = value

    def to_dict(self) -> dict:
        d = {}
        for name, _ in self.__class__._meta.fields:
            d[name] = getattr(self, name)
        return d


class RLPSignedTx(rlp.Serializable):
    fields = [
        ('nonce', big_endian_int),
        ('gasprice', big_endian_int),
        ('startgas', big_endian_int),
        ('to', Binary.fixed_length(20, allow_empty=True)),
        ('value', big_endian_int),
        ('data', binary),
        ('v', big_endian_int),
        ('r', big_endian_int),
        ('s', big_endian_int),
    ]

    def __init__(self, nonce: int, gasprice: int, startgas: int, to: bytes, value: int, data: str,
                 v: int, r: int, s: int):
        super(RLPSignedTx, self).__init__(nonce, gasprice, startgas, to, value, data, v, r, s)

    def sender(self, value: str) -> None:
        self._sender = value

    def to_dict(self) -> dict:
        d = {}
        for name, _ in self.__class__._meta.fields:
            d[name] = getattr(self, name)
        return d

==> ledgereth-0.1.2.tar.gz: ledgereth-0.1.2/ledgereth/objects.py <==
import rlp
from rlp.sedes import big_endian_int, binary, Binary
from eth_utils import to_normalized_address

from ledgereth.utils import is_bytes, is_bip32_path, parse_bip32_path


class ISO7816Command:
    def __init__(self, CLA: bytes, INS: bytes, P1: bytes, P2: bytes, Lc: bytes = None,
                 Le: bytes = None, data: bytes = None):
        try:
            assert is_bytes(CLA)
            assert is_bytes(INS)
            assert is_bytes(P1)
            assert is_bytes(P2)
            assert is_bytes(Lc) or Lc is None
            assert is_bytes(Le) or Le is None
            assert is_bytes(data) or data is None
        except AssertionError:
            raise ValueError("Command parts must be type bytes")

        self.CLA = CLA
        self.INS = INS
        self.P1 = P1
        self.P2 = P2
        self.Lc = Lc or b'\x00'
        self.Le = Le
        self.data = data

    def set_data(self, data: bytes, Lc: bytes = None) -> None:
        self.data = data
        if len(self.data) > 255:
            # TODO: Warning?
            return
        if Lc is None:
            self.Lc = len(self.data).to_bytes(1, 'big')
        else:
            self.Lc = Lc

    def encode(self) -> bytes:
        encoded = self.CLA + self.INS + self.P1 + self.P2
        if self.data is not None:
            if self.Lc is None:
                self.Lc = (len(self.data)).to_bytes(1, 'big')
            encoded += self.Lc
            encoded += self.data
        else:
            encoded += self.Lc
        if self.Le is not None:
            encoded += self.Le
        return encoded

    def encode_hex(self) -> str:
        return self.encode().hex()


class LedgerAccount:
    def __init__(self, path, address):
        if not is_bip32_path(path):
            raise ValueError('Invalid BIP32 Ethereum path')

        self.path = path
        self.path_encoded = parse_bip32_path(path)
        self.address = to_normalized_address(address)


class Transaction(rlp.Serializable):
    fields = [
        ('nonce', big_endian_int),
        ('gasprice', big_endian_int),
        ('startgas', big_endian_int),
        ('to', Binary.fixed_length(20, allow_empty=True)),
        ('value', big_endian_int),
        ('data', binary),
    ]

    def __init__(self, nonce: int, gasprice: int, startgas: int, to: bytes, value: int, data: str):
        super(RLPTx, self).__init__(nonce, gasprice, startgas, to, value, data)

    def sender(self, value: str) -> None:
        self._sender = value

    def to_dict(self) -> dict:
        d = {}
        for name, _ in self.__class__._meta.fields:
            d[name] = getattr(self, name)
        return d


class SignedTransaction(rlp.Serializable):
    fields = [
        ('nonce', big_endian_int),
        ('gasprice', big_endian_int),
        ('startgas', big_endian_int),
        ('to', Binary.fixed_length(20, allow_empty=True)),
        ('value', big_endian_int),
        ('data', binary),
        ('v', big_endian_int),
        ('r', big_endian_int),
        ('s', big_endian_int),
    ]

    def __init__(self, nonce: int, gasprice: int, startgas: int, to: bytes, value: int, data: str,
                 v: int, r: int, s: int):
        super(SignedTransaction, self).__init__(nonce, gasprice, startgas, to, value, data, v, r, s)

    def sender(self, value: str) -> None:
        self._sender = value

    def to_dict(self) -> dict:
        d = {}
        for name, _ in self.__class__._meta.fields:
            d[name] = getattr(self, name)
        return d


# Compat: Depreciated
RLPTx = Transaction
RLPSignedTx = SignedTransaction
